import argparse
import tempfile
import qrcode
from fpdf import FPDF


def main(argv=None):
    file_format = ["PNG", "PDF", "BOTH"]
    parser = argparse.ArgumentParser(
        prog="python -m wifipass",
    )
    parser.add_argument("--ssid", required=True, help="network name")
    parser.add_argument("--pw", required=True, help="network password")
    parser.add_argument("--format", required=True, choices=file_format)
    parser.add_argument("--out", required=False, help="basename for the outputfile(s)")
    args = parser.parse_args(argv)

    use_format = args.format
    ssid = args.ssid
    pw = args.pw
    if args.out:
        out_name = args.out
    else:
        out_name = f"wifipass_{ssid}"

    img = qrcode.make(f"WIFI:T:WPA;S:{ssid};P:{pw};;")

    if use_format == "PNG" or use_format == "BOTH":
        img.save(f"{out_name}.png", format="PNG")
    elif use_format == "PDF" or use_format == "BOTH":
        fp = tempfile.NamedTemporaryFile()
        img.save(fp, format="PNG")
        pdf = FPDF()
        pdf.add_page(orientation="P")
        pdf.set_font("Arial", "", 14)
        pdf.write(5, f"SSID: {ssid}\nPW: {pw}\n")
        pdf.image(fp.name, 0, None, 200, 200, type="PNG")
        pdf.output(f"{out_name}.pdf")
        fp.close()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['wifipass']

package_data = \
{'': ['*']}

install_requires = \
['Pillow>=9.1.0,<10.0.0', 'fpdf>=1.7.2,<2.0.0', 'qrcode>=7.3.1,<8.0.0']

entry_points = \
{'console_scripts': ['wifiPass = wifiPass:main']}

setup_kwargs = {
    'name': 'wifipass',
    'version': '0.0.2',
    'description': 'Creates a PDF with a QR code of your wifi password.',
    'long_description': '# wifipass\nA tool to create QR codes to share your wifi credentials.\n\n# Prerequisites\nYou need to have `python3` and `pip` installed.\n\n# Installing\n```\npip install wifiPass-propellerpain\n```\n\n# Running\n```\nusage: python -m wifiPass [-h] --ssid SSID --pw PW --format {PNG,PDF,BOTH}\n                   [--out OUT]\n\noptional arguments:\n  -h, --help            show this help message and exit\n  --ssid SSID           network name\n  --pw PW               network password\n  --format {PNG,PDF,BOTH}\n  --out OUT             basename for the outputfile(s)\n  ```\n  For example to generate a pdf version:\n  ```\n  python -m wifiPass --ssid YOUR_SSID_HERE --pw YOUR_PW_HERE --format PDF\n  ```\n',
    'author': 'Pierre',
    'author_email': 'pierre.git@posteo.de',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7',
}


setup(**setup_kwargs)
